==> haskell-wl-pprint-text-1.2.0.0-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wl-pprint-text.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wl-pprint-text
version: 1.2.0.0
id: wl-pprint-text-1.2.0.0-4vcBGzCLEmsFxQDAtPrBUl
key: wl-pprint-text-1.2.0.0-4vcBGzCLEmsFxQDAtPrBUl
license: BSD-3-Clause
copyright: 2007 Daan Leijen, 2010 Ivan Lazar Miljenovic
maintainer: Ivan.Miljenovic@gmail.com
author: Ivan Lazar Miljenovic
synopsis: A Wadler/Leijen Pretty Printer for Text values
description:
    A clone of wl-pprint for use with the text library.
category: Text
abi: d3ee0212d106c3ccf44fbf1225a55b2d
exposed: True
exposed-modules:
    Text.PrettyPrint.Leijen.Text Text.PrettyPrint.Leijen.Text.Monadic
import-dirs: /usr/lib/ghc-8.4.3/site-local/wl-pprint-text-1.2.0.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/wl-pprint-text-1.2.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/wl-pprint-text-1.2.0.0
hs-libraries: HSwl-pprint-text-1.2.0.0-4vcBGzCLEmsFxQDAtPrBUl
depends:
    base-4.11.1.0 base-compat-0.10.1-LjQCAvvrOQx72iD1hHVjc6
    text-1.2.3.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base-compat-0.10.1-LjQCAvvrOQx72iD1hHVjc6=d62b8bf62b1a5e2bfe5d3dedbe6980ab
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
haddock-interfaces: /usr/share/doc/haskell-wl-pprint-text/html/wl-pprint-text.haddock
haddock-html: /usr/share/doc/haskell-wl-pprint-text/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wl-pprint-text-1.2.0.0-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wl-pprint-text.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wl-pprint-text
version: 1.2.0.0
id: wl-pprint-text-1.2.0.0-CY4tTlrSvXA5WAM0uk0Uk1
key: wl-pprint-text-1.2.0.0-CY4tTlrSvXA5WAM0uk0Uk1
license: BSD-3-Clause
copyright: 2007 Daan Leijen, 2010 Ivan Lazar Miljenovic
maintainer: Ivan.Miljenovic@gmail.com
author: Ivan Lazar Miljenovic
synopsis: A Wadler/Leijen Pretty Printer for Text values
description:
    A clone of wl-pprint for use with the text library.
category: Text
abi: 07bd6baa6ebf161b190981e09cdc9094
exposed: True
exposed-modules:
    Text.PrettyPrint.Leijen.Text Text.PrettyPrint.Leijen.Text.Monadic
import-dirs: /usr/lib/ghc-8.4.3/site-local/wl-pprint-text-1.2.0.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/wl-pprint-text-1.2.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/wl-pprint-text-1.2.0.0
hs-libraries: HSwl-pprint-text-1.2.0.0-CY4tTlrSvXA5WAM0uk0Uk1
depends:
    base-4.11.1.0 base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ
    text-1.2.3.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ=d7511a9b0b5b14c2ec3659e1cd285aec
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
haddock-interfaces: /usr/share/doc/haskell-wl-pprint-text/html/wl-pprint-text.haddock
haddock-html: /usr/share/doc/haskell-wl-pprint-text/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
